@@ -164,7 +164,7 @@ class Simulation:
         return (truncationNumber, totalSVDPower)
 
     def GetTruncationNumberFromDesiredPower(self, desiredSVDPower):
-        singularVectorPowers = self.simulation.singularValues/np.sum(self.simulation.singularValues)
+        singularVectorPowers = self.singularValues/np.sum(self.singularValues)
         totalSVDPower=0; numSVDComponents=0
         for singularVectorPower in singularVectorPowers:
             totalSVDPower += singularVectorPower
@@ -174,7 +174,7 @@ class Simulation:
         return numSVDComponents, totalSVDPower
 
     def GetPowerFromDesiredTruncationNumber(self, desiredTruncationNumber):
-        singularVectorPowers = self.simulation.singularValues/np.sum(self.simulation.singularValues)
+        singularVectorPowers = self.singularValues/np.sum(self.singularValues)
         totalSVDPower=np.sum(singularVectorPowers[0:desiredTruncationNumber])
         return totalSVDPower
 
